@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package WebService::Nestoria::Search;
-$WebService::Nestoria::Search::VERSION = '1.022005';
+$WebService::Nestoria::Search::VERSION = '1.022006';
 use Carp;
 use URI;
 use WebService::Nestoria::Search::Request;
@@ -14,7 +14,7 @@ WebService::Nestoria::Search - Perl interface to the Nestoria Search public API.
 
 =head1 VERSION
 
-version 1.022005
+version 1.022006
 
 =head1 SYNOPSIS
 
@@ -157,14 +157,15 @@ my %Config = (
     },
 
     'Urls' => {
-        'uk'                  => 'http://api.nestoria.co.uk/api',
-        'es'                  => 'http://api.nestoria.es/api',
-        'de'                  => 'http://api.nestoria.de/api',
-        'it'                  => 'http://api.nestoria.it/api',
-        'fr'                  => 'http://api.nestoria.fr/api',
         'au'                  => 'http://api.nestoria.com.au/api',
         'br'                  => 'http://api.nestoria.com.br/api',
+        'de'                  => 'http://api.nestoria.de/api',
+        'es'                  => 'http://api.nestoria.es/api',
+        'fr'                  => 'http://api.nestoria.fr/api',
         'in'                  => 'http://api.nestoria.in/api',
+        'it'                  => 'http://api.nestoria.it/api',
+        'mx'                  => 'http://api.nestoria.mx/api',
+        'uk'                  => 'http://api.nestoria.co.uk/api',
     },
 );
 
@@ -657,6 +658,8 @@ Currently the available countries are:
 
 =item * it - Italy
 
+=item * mx - Mexico
+
 =item * uk - United Kingdom
 
 =back
